const path = require('path');

module.exports = {
  root: true,
  parser: '@typescript-eslint/parser',
  plugins: ['prettier', '@typescript-eslint', '@stylexjs'],
  env: {
    node: true,
    jest: true,
  },
  globals: {
    window: true,
  },
  parserOptions: {
    tsconfigRootDir: __dirname,
    project: ['./tsconfig.json'],
  },
  settings: {
    'import/resolver': {
      node: {},
      webpack: {
        config: path.resolve(__dirname, 'dev.webpack.config.js'),
      },
    },
  },
  extends: [
    'airbnb',
    'airbnb-typescript',
    'plugin:@typescript-eslint/recommended-requiring-type-checking',
    'plugin:prettier/recommended',
  ],
  rules: {
    '@stylexjs/valid-styles': 'error',
    '@typescript-eslint/no-unused-vars': [
      'error',
      {
        varsIgnorePattern: '^_',
        argsIgnorePattern: '^_',
        ignoreRestSiblings: true,
      },
    ],
    '@typescript-eslint/no-explicit-any': 'error',
    'react/jsx-filename-extension': [
      'error',
      {
        extensions: ['.js', '.tsx'],
      },
    ],
    'react/prop-types': 'Off',
    'react/no-unused-prop-types': 'Off',
    'react/state-in-constructor': 'Off',
    'react/default-props-match-prop-types': 'Off',
    'react/jsx-no-useless-fragment': 'Off',
    'react/no-unstable-nested-components': 'Off',
    'react/no-unused-class-component-methods': 'Off',
    'react/jsx-no-constructed-context-values': 'Off',
    'class-methods-use-this': 'Off',
    'default-param-last': 'Off',
    'func-names': 'Off',
    'global-require': 'Off',
    'no-plusplus': 'Off',
    'no-underscore-dangle': 'Off',
    'import/prefer-default-export': 'Off',
    'import/extensions': 'Off',
    'import/no-import-module-exports': 'Off',
    'no-prototype-builtins': 'Off',
    'no-multi-assign': 'Off',
    'no-restricted-exports': 'Off',
    'prefer-exponentiation-operator': 'Off',
    'react/jsx-props-no-spreading': 'Off',
    'react/destructuring-assignment': 'Off',
    'react/forbid-prop-types': 'Off',
    'react/function-component-definition': 'Off',
    'react/require-default-props': 'Off',
    'react/sort-comp': 'Off',
    'react/no-unused-state': 'Off',
    'no-shadow': 'Off',
    'import/no-cycle': 'Off',
    '@typescript-eslint/no-use-before-define': 'Off',
    '@typescript-eslint/camelcase': 'Off',
    '@typescript-eslint/unbound-method': 'Off',
    '@typescript-eslint/naming-convention': 'Off',
    '@typescript-eslint/no-unsafe-assignment': 'Off',
    '@typescript-eslint/no-unsafe-member-access': 'Off',
    '@typescript-eslint/no-unsafe-call': 'Off',
    '@typescript-eslint/no-unsafe-return': 'Off',
    '@typescript-eslint/no-unsafe-argument': 'Off',
    '@typescript-eslint/no-floating-promises': 'Off',
    '@typescript-eslint/ban-ts-comment': 'Off',
    '@typescript-eslint/restrict-template-expressions': 'Off',
    '@typescript-eslint/restrict-plus-operands': 'Off',
    '@typescript-eslint/default-param-last': 'Off',
    '@typescript-eslint/return-await': 'Off',
    'react/static-property-placement': 'Off',
    // Enable when in a11y fix sweep
    'jsx-a11y/no-static-element-interactions': 'Off',
    'jsx-a11y/click-events-have-key-events': 'Off',
    'jsx-a11y/anchor-is-valid': 'Off',
    'jsx-a11y/mouse-events-have-key-events': 'Off',
    'jsx-a11y/label-has-associated-control': [
      'error',
      {
        labelAttributes: ['id'],
      },
    ],
    'jsx-a11y/control-has-associated-label': 'Off',
  },
};
