/* eslint-disable import/no-extraneous-dependencies */
const path = require('path');
const { merge } = require('webpack-merge');
const webpack = require('webpack');
const UnusedWebpackPlugin = require('unused-webpack-plugin');
const CopyPlugin = require('copy-webpack-plugin');
const baseConfig = require('./base.webpack.config.js');

module.exports = merge(baseConfig, {
  devtool: 'cheap-module-source-map',
  mode: 'development',
  entry: ['webpack-hot-middleware/client', './src/index.tsx'],
  module: {
    rules: [
      {
        test: /\.((c|sa|sc)ss)$/i,
        include: /\.module\.((c|sa|sc)ss)$/,
        use: [
          'style-loader',
          {
            loader: 'css-loader',
            options: {
              modules: {
                exportLocalsConvention: 'camelCase',
              },
              importLoaders: 3,
            },
          },
          'postcss-loader',
          'sass-loader',
          {
            loader: 'sass-resources-loader',
            options: {
              resources: [
                './src/styles/_mixins.scss',
                './src/styles/_variables.scss',
              ],
            },
          },
        ],
      },
      {
        test: /\.((c|sa|sc)ss)$/i,
        exclude: /\.module\.((c|sa|sc)ss)$/,
        use: [
          'style-loader',
          {
            loader: 'css-loader',
            options: {
              importLoaders: 2,
            },
          },
          'postcss-loader',
          'sass-loader',
        ],
      },
    ],
  },
  output: {
    publicPath: '/',
  },
  plugins: [
    new webpack.HotModuleReplacementPlugin(),
    new UnusedWebpackPlugin({
      directories: [path.join(__dirname, 'src')],
      exclude: [
        '*.spec.js',
        '*.spec.ts',
        'types/**/*.*',
        'styles/**/*.*',
        'public/**/*.*',
      ],
      root: __dirname,
    }),
  ],
});
