/* eslint-disable import/no-extraneous-dependencies */
const path = require('path');
const StylexPlugin = require('@stylexjs/webpack-plugin');
const { merge } = require('webpack-merge');
const SaveAssetsJson = require('assets-webpack-plugin');
const CopyPlugin = require('copy-webpack-plugin');
const baseConfig = require('./base.webpack.config.js');

module.exports = merge(baseConfig, {
  bail: true,
  entry: ['./src/index.tsx'],
  mode: 'production',
  output: {
    publicPath: '/build/',
    filename: '[name].[contenthash].bundle.js',
    chunkFilename: '[name].[contenthash].chunk.js',
  },
  plugins: [
    // Ensure that the stylex plugin is used before Babel
    new StylexPlugin({
      filename: 'styleX.generated.styles.[contenthash].css',
      // get webpack mode and set value for dev
      dev: false,
      // Use statically generated CSS files and not runtime injected CSS.
      // Even in development.
      runtimeInjection: false,
      // optional. default: 'x'
      classNamePrefix: 'x',
      // Required for CSS variable support
      unstable_moduleResolution: {
        // type: 'commonJS' | 'haste'
        // default: 'commonJS'
        type: 'commonJS',
        // The absolute path to the root directory of your project
        rootDir: __dirname,
      },
    }),
    new SaveAssetsJson({
      path: path.resolve(__dirname, 'server'),
      filename: 'assets.json',
    }),
  ],
});
